@@ -29,8 +29,8 @@ class FALKON_EXPORT Menu : public QMenu
 {
     Q_OBJECT
 public:
-    explicit Menu(QWidget* parent = 0);
-    explicit Menu(const QString &title, QWidget* parent = 0);
+    explicit Menu(QWidget* parent = nullptr);
+    explicit Menu(const QString &title, QWidget* parent = nullptr);
 
     // Default is false, menu will NOT be closed on middle click
     bool closeOnMiddleClick() const;
@@ -47,16 +47,16 @@ private:
 
     void closeAllMenus();
 
-    bool m_closeOnMiddleClick;
+    bool m_closeOnMiddleClick = false;
 };
 
 class FALKON_EXPORT Action : public QAction
 {
     Q_OBJECT
 public:
-    explicit Action(QObject* parent = 0);
-    explicit Action(const QString &text, QObject* parent = 0);
-    explicit Action(const QIcon &icon, const QString &text, QObject* parent = 0);
+    explicit Action(QObject* parent = nullptr);
+    explicit Action(const QString &text, QObject* parent = nullptr);
+    explicit Action(const QIcon &icon, const QString &text, QObject* parent = nullptr);
 
 Q_SIGNALS:
     void ctrlTriggered();
