@@ -32,6 +32,7 @@
 #include <QWidget>
 #include <QApplication>
 #include <QSslCertificate>
+#include <QLocale>
 #include <QScreen>
 #include <QUrl>
 #include <QIcon>
@@ -378,18 +379,20 @@ QString QzTools::fileSizeToString(qint64 size)
         return QObject::tr("Unknown size");
     }
 
+    QLocale locale;
+
     double _size = size / 1024.0; // KB
     if (_size < 1000) {
-        return QString::number(_size > 1 ? _size : 1, 'f', 0) + QLatin1Char(' ') + QObject::tr("KB");
+        return QObject::tr("%1 kB").arg(locale.toString(_size > 1 ? _size : 1, 'f', 0));
     }
 
     _size /= 1024; // MB
     if (_size < 1000) {
-        return QString::number(_size, 'f', 1) + QLatin1Char(' ') + QObject::tr("MB");
+        return QObject::tr("%1 MB").arg(locale.toString(_size, 'f', 1));
     }
 
     _size /= 1024; // GB
-    return QString::number(_size, 'f', 2) + QLatin1Char(' ') + QObject::tr("GB");
+    return QObject::tr("%1 GB").arg(locale.toString(_size, 'f', 2));
 }
 
 QPixmap QzTools::createPixmapForSite(const QIcon &icon, const QString &title, const QString &url)
