@@ -153,14 +153,14 @@ WebTab::WebTab(QWidget *parent)
     m_layout->setSpacing(0);
     m_layout->addWidget(m_webView);
 
-    QWidget *viewWidget = new QWidget(this);
+    auto *viewWidget = new QWidget(this);
     viewWidget->setLayout(m_layout);
 
     m_splitter = new QSplitter(Qt::Vertical, this);
     m_splitter->setChildrenCollapsible(false);
     m_splitter->addWidget(viewWidget);
 
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
     layout->addWidget(m_splitter);
@@ -169,16 +169,16 @@ WebTab::WebTab(QWidget *parent)
     m_notificationWidget = new QWidget(this);
     m_notificationWidget->setAutoFillBackground(true);
     QPalette pal = m_notificationWidget->palette();
-    pal.setColor(QPalette::Background, pal.window().color().darker(110));
+    pal.setColor(QPalette::Window, pal.window().color().darker(110));
     m_notificationWidget->setPalette(pal);
 
-    QVBoxLayout *nlayout = new QVBoxLayout(m_notificationWidget);
+    auto *nlayout = new QVBoxLayout(m_notificationWidget);
     nlayout->setSizeConstraint(QLayout::SetMinAndMaxSize);
     nlayout->setContentsMargins(0, 0, 0, 0);
     nlayout->setSpacing(1);
 
-    connect(m_webView, SIGNAL(showNotification(QWidget*)), this, SLOT(showNotification(QWidget*)));
-    connect(m_webView, SIGNAL(loadFinished(bool)), this, SLOT(loadFinished()));
+    connect(m_webView, &WebView::showNotification, this, &WebTab::showNotification);
+    connect(m_webView, &QWebEngineView::loadFinished, this, &WebTab::loadFinished);
     connect(m_webView, &TabbedWebView::titleChanged, this, &WebTab::titleWasChanged);
     connect(m_webView, &TabbedWebView::titleChanged, this, &WebTab::titleChanged);
     connect(m_webView, &TabbedWebView::iconChanged, this, &WebTab::iconChanged);
@@ -221,12 +221,14 @@ void WebTab::showWebInspector(bool inspectElement)
     if (!WebInspector::isEnabled() || haveInspector())
         return;
 
-    WebInspector *inspector = new WebInspector(this);
+    auto *inspector = new WebInspector(this);
     inspector->setView(m_webView);
     if (inspectElement)
         inspector->inspectElement();
 
+    const int height = inspector->sizeHint().height();
     m_splitter->addWidget(inspector);
+    m_splitter->setSizes({m_splitter->height() - height, height});
 }
 
 void WebTab::toggleWebInspector()
@@ -237,7 +239,7 @@ void WebTab::toggleWebInspector()
         delete m_splitter->widget(1);
 }
 
-void WebTab::showSearchToolBar()
+void WebTab::showSearchToolBar(const QString &searchText)
 {
     const int index = 1;
 
@@ -252,6 +254,9 @@ void WebTab::showSearchToolBar()
     }
 
     Q_ASSERT(toolBar);
+    if (!searchText.isEmpty()) {
+        toolBar->setText(searchText);
+    }
     toolBar->focusSearchLine();
 }
 
@@ -328,7 +333,7 @@ void WebTab::detach()
 
     if (m_isCurrentTab) {
         m_isCurrentTab = false;
-        emit currentTabChanged(m_isCurrentTab);
+        Q_EMIT currentTabChanged(m_isCurrentTab);
     }
     m_tabBar->disconnect(this);
 
@@ -352,7 +357,7 @@ void WebTab::attach(BrowserWindow* window)
         const bool wasCurrent = m_isCurrentTab;
         m_isCurrentTab = index == tabIndex();
         if (wasCurrent != m_isCurrentTab) {
-            emit currentTabChanged(m_isCurrentTab);
+            Q_EMIT currentTabChanged(m_isCurrentTab);
         }
     };
 
@@ -396,7 +401,7 @@ void WebTab::load(const LoadRequest &request)
 void WebTab::unload()
 {
     m_savedTab = SavedTab(this);
-    emit restoredChanged(isRestored());
+    Q_EMIT restoredChanged(isRestored());
     m_webView->setPage(new WebPage);
     m_webView->setFocus();
 }
@@ -422,7 +427,7 @@ void WebTab::setPinned(bool state)
     }
 
     m_isPinned = state;
-    emit pinnedChanged(m_isPinned);
+    Q_EMIT pinnedChanged(m_isPinned);
 }
 
 bool WebTab::isMuted() const
@@ -480,7 +485,7 @@ void WebTab::setParentTab(WebTab *tab)
         const int index = m_parentTab->m_childTabs.indexOf(this);
         if (index >= 0) {
             m_parentTab->m_childTabs.removeAt(index);
-            emit m_parentTab->childTabRemoved(this, index);
+            Q_EMIT m_parentTab->childTabRemoved(this, index);
         }
     }
 
@@ -490,7 +495,7 @@ void WebTab::setParentTab(WebTab *tab)
         m_parentTab = nullptr;
         tab->addChildTab(this);
     } else {
-        emit parentTabChanged(m_parentTab);
+        Q_EMIT parentTabChanged(m_parentTab);
     }
 }
 
@@ -506,7 +511,7 @@ void WebTab::addChildTab(WebTab *tab, int index)
         const int index = oldParent->m_childTabs.indexOf(tab);
         if (index >= 0) {
             oldParent->m_childTabs.removeAt(index);
-            emit oldParent->childTabRemoved(tab, index);
+            Q_EMIT oldParent->childTabRemoved(tab, index);
         }
     }
 
@@ -520,9 +525,9 @@ void WebTab::addChildTab(WebTab *tab, int index)
     }
 
     m_childTabs.insert(index, tab);
-    emit childTabAdded(tab, index);
+    Q_EMIT childTabAdded(tab, index);
 
-    emit tab->parentTabChanged(this);
+    Q_EMIT tab->parentTabChanged(this);
 }
 
 QVector<WebTab*> WebTab::childTabs() const
@@ -554,7 +559,7 @@ void WebTab::restoreTab(const WebTab::SavedTab &tab)
 
     if (!isPinned() && qzSettings->loadTabsOnActivation) {
         m_savedTab = tab;
-        emit restoredChanged(isRestored());
+        Q_EMIT restoredChanged(isRestored());
         int index = tabIndex();
 
         m_tabBar->setTabText(index, tab.title);
@@ -634,7 +639,7 @@ void WebTab::tabActivated()
         }
         p_restoreTab(m_savedTab);
         m_savedTab.clear();
-        emit restoredChanged(isRestored());
+        Q_EMIT restoredChanged(isRestored());
     });
 }
 
